from django.shortcuts import render
from django.conf import settings
from django.http import HttpResponseNotFound
from django.utils.module_loading import import_string


def personal_information(request, template_name='customers/personal_information.html'):
    user = request.user
    context = {
        'user': user,
        'customer_menu': settings.PCART_CUSTOMER_PROFILE_SECTIONS,
    }
    return render(request, template_name, context)


def profile_section(request, slug):
    for section in settings.PCART_CUSTOMER_PROFILE_SECTIONS:
        if slug == section['slug']:
            view = import_string(section['view'])
            kwargs = section.get('kwargs', dict())
            return view(request, **kwargs)
    return HttpResponseNotFound('Unknown profile section')


def customer_toolbar(request, template_name='customers/includes/_customer_toolbar_content.html'):
    user = request.user
    context = {
        'user': user,
    }
    return render(request, template_name, context)



from .models import Customer


def get_customer(request, create=True):
    if request.user.is_authenticated:
        customer = Customer.objects.get(user=request.user)
    else:
        try:
            customer = Customer.objects.get(session_id=request.session.session_key)
        except Customer.DoesNotExist:
            if create:
                if not request.session.exists(request.session.session_key):
                    request.session.create()
                customer = Customer.objects.create(session_id=request.session.session_key)
                request.session['customer_id'] = str(customer.id)
            else:
                customer = None
    return customer



from django.conf.urls import url
from django.contrib.auth import views as auth_views
from .forms import UserPasswordResetForm
from . import views


urlpatterns = [
    url(
        r'^login/$', auth_views.login,
        {'template_name': 'customers/login.html'}, name='login'),
    url(r'^logout/$', auth_views.logout, name='logout'),
    # url(
    #     r'^register/$', register_view,
    #     name='register'),
    # url(r'^register/success/$',
    #     TemplateView.as_view(
    #         template_name='accounts/registration_success.html'),
    #     name='registration_success'),
    url(
        r'^password-change/$',
        auth_views.password_change,
        {
            'template_name': 'customers/password_change_form.html',
            'post_change_redirect': 'pcart_customers:password-change-done',
        },
        name='password-change'),
    url(
        r'^password-change/done/$',
        auth_views.password_change_done,
        {'template_name': 'customers/password_change_done.html'},
        name='password-change-done'),
    url(
        r'^password-reset/$',
        auth_views.password_reset,
        {
            'template_name': 'customers/password_reset_form.html',
            'password_reset_form': UserPasswordResetForm},
        name='password_reset'),
    url(
        r'^password-reset/done/$',
        auth_views.password_reset_done,
        {'template_name': 'customers/password_reset_done.html'},
        name='password_reset_done'),
    url(
        r'^password-reset/(?P<uidb64>.+)/(?P<token>.+)/confirm/$',
        auth_views.password_reset_confirm,
        {'template_name': 'customers/password_reset_confirm.html'},
        name='password_reset_confirm'),
    url(
        r'^password-reset/complete/$',
        auth_views.password_reset_complete,
        {'template_name': 'customers/password_reset_complete.html'},
        name='password_reset_complete'),

    url(r'^personal-information/$', views.personal_information, name='personal-information'),
    url(r'^customer-toolbar/$', views.customer_toolbar, name='customer-toolbar'),
    url(r'^(?P<slug>[\w\d-]+)/$', views.profile_section, name='customer-profile-section'),
]
